<?php





function db_query($sql, $dbcon = null) {


    if (MYSQLI_STATUS == 'Y') {


        $result = mysqli_query($GLOBALS['con'], $sql);


        if (!$result) {


            db_error($sql);


            return false;


        }


    } else {


        $result = mysql_query($sql) or die(mysql_error());


    }


    return $result;


}





function db_fetch_array($qry) {


    if (!$qry) return false;





    if (MYSQLI_STATUS == 'Y') {		


        $res = mysqli_fetch_array($qry);


    } else {


        $res = mysql_fetch_array($qry);


    }


    return $res;


}





function db_fetch_assoc($qry) {


    if (!$qry) return false;





    if (MYSQLI_STATUS == 'Y') {		


        $res = mysqli_fetch_assoc($qry);


    } else {


        $res = mysql_fetch_assoc($qry);


    }


    return $res;


}





function db_num_rows($qry) {


    if (!$qry) {


        if (MYSQLI_STATUS == 'Y') {


            echo "<b>Database Error:</b> " . mysqli_error($GLOBALS['con']);


        } else {


            echo "<b>Database Error:</b> " . mysql_error();


        }


        return 0;


    }





    if (MYSQLI_STATUS == 'Y') {		


        $res = mysqli_num_rows($qry);


    } else {


        $res = mysql_num_rows($qry);


    }	


    return $res;


}





function db_real_escape($val) {


    return mysqli_real_escape_string($GLOBALS['con'], $val);


}





function db_insert_id() {


    if (MYSQLI_STATUS == 'Y') {		


        return mysqli_insert_id($GLOBALS['con']);


    } else {


        return mysql_insert_id($GLOBALS['con']);


    }


}





function db_error($sql) {


    echo "<div style='font-family: tahoma; font-size: 11px; color: #333333'><br>";





    if (MYSQLI_STATUS == 'Y') {	


        echo mysqli_error($GLOBALS['con']);


    } else {


        echo mysql_error();


    }





    print_error();





    if (defined('LOCAL_MODE') && LOCAL_MODE) {


        echo "<br><b>SQL:</b> $sql";


    }





    echo "</div>";


}





function print_error() {


    $debug_backtrace = debug_backtrace();


    for ($i = 1; $i < count($debug_backtrace); $i++) {


        $error = $debug_backtrace[$i];


        echo "<br><div>";


        echo "<b>File:</b> " . $error['file'] . "<br>";


        echo "<b>Line:</b> " . $error['line'] . "<br>";


        echo "<b>Function:</b> " . $error['function'] . "<br>";


        echo "</div>";


    }


}


?>


